@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AddPrereqs;
 
 our $DATE = '2015-03-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -42,7 +42,7 @@ sub _add_prereq {
     my ($self, $mod, $ver) = @_;
     return if defined($self->{_added_prereqs}{$mod}) &&
         $self->{_added_prereqs}{$mod} >= $ver;
-    $self->log_debug("Adding prereq: $mod => $ver");
+    $self->log("Adding prereq: $mod => $ver");
     $self->zilla->register_prereqs({phase=>'runtime'}, $mod, $ver);
     $self->{_added_prereqs}{$mod} = $ver;
 }
@@ -161,7 +161,7 @@ Dist::Zilla::Plugin::Rinci::AddPrereqs - Add prerequisites from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2015-03-13.
+This document describes version 0.03 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2015-03-13.
 
 =head1 SYNOPSIS
 
